==> a2ps-4.8.4.tar.gz: a2ps-4.8.4/acconfig.h <==
/* Special definitions, processed by autoheader. */

/* Here is defined the name of the current package */
#undef PACKAGE

/* Here is defined the version of a2ps */
#undef VERSION

/* Define to 1 if prototypes are supported */
#undef PROTOTYPES

/* Define to unsigned char is does not exist */
#undef uchar

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define to the way file should be called to follow the links */
#undef FILE_LINK

/* This is only relevant for Ogonkify, but required by autoheader */
#undef ibmfonts

/* This is the char used to separate component of a path */
#undef DIR_SEP

/* This is the char used to separate paths */
#undef PATH_SEP

/* Define to gnu_strftime if the replacement function should be used.  */
#undef strftime

/* Define to rpl_fnmatch if the replacement function should be used.  */
#undef fnmatch

/* Define to rpl_mktime if the replacement function should be used.  */
#undef mktime

/* Because some auxiliary functions (e.g., fnmatch) need this */
#undef _GNU_SOURCE

@BOTTOM@

/* Please, do not change this */
#ifndef PARAMS
# if defined (__GNUC__) || __STDC__
#  define PARAMS(args) args
# else
#  define PARAMS(args) ()
# endif
#endif


#ifndef __P
# if defined (__GNUC__) || __STDC__
# define __P(args) args
# else
#  define __P(args) ()
# endif
#endif

==> a2ps_4.10.2.orig.tar.gz: a2ps-4.10.2/acconfig.h <==
/* Special definitions, processed by autoheader. */

/* Here is defined the name of the current package */
#undef PACKAGE

/* Here is defined the version of a2ps */
#undef VERSION

/* Define to 1 if prototypes are supported */
#undef PROTOTYPES

/* Define to unsigned char if does not exist */
#undef uchar

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define as 1 if you have the obstack functions.  */
#undef HAVE_OBSTACK

/* This is the char used to separate component of a path */
#undef DIR_SEP

/* This is the char used to separate paths */
#undef PATH_SEP

/* We want regex to use syntax tables */
#undef SYNTAX_TABLE

/* Do we use a debugging malloc? */
#undef WITH_DMALLOC

/* Should strdup, strcpy etc. have their arguments checked? */
#undef DMALLOC_FUNC_CHECK

/* Define to gnu_strftime if the replacement function should be used.  */
#undef strftime

/* Define to rpl_fnmatch if the replacement function should be used.  */
#undef fnmatch

/* Define to rpl_mktime if the replacement function should be used.  */
#undef mktime

/* Define to rpl_getopt if the replacement function should be used,
 * And define the rpl_* if the replacement getopt is used */
#undef getopt
#undef optarg
#undef opterr
#undef optind
#undef optopt

/* Define to rpl_exit if the replacement function should be used.  */
#undef exit

/* Define if your struct passwd has pw_gecos.  */
#undef HAVE_PW_GECOS
